@@ -31,7 +31,7 @@ var searchData=
   ['addaccessibleeventlistener',['addAccessibleEventListener',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleEventBroadcaster.html#ae41c29350e4281b778463ac83305a512',1,'com::sun::star::accessibility::XAccessibleEventBroadcaster']]],
   ['addactionlistener',['addActionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XButton.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XButton::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XComboBox::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XFixedHyperlink.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XFixedHyperlink::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XImageButton.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XImageButton::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#a7ffbc5096d58bb272723ad6d20e1e5e8',1,'com::sun::star::awt::XListBox::addActionListener()'],['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XHyperlinkControl.html#a74ecae386bb0df48f0c08877ed746d92',1,'com::sun::star::inspection::XHyperlinkControl::addActionListener()']]],
   ['addactionlock',['addActionLock',['../interfacecom_1_1sun_1_1star_1_1document_1_1XActionLockable.html#ae524582ad7f13a8cc05cb9236e7a7635',1,'com::sun::star::document::XActionLockable']]],
-  ['addactivatelistener',['addActivateListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFormController.html#a70575cef0b57cf8e7bb07f401e97add8',1,'com::sun::star::form::runtime::XFormController::addActivateListener()'],['../interfacecom_1_1sun_1_1star_1_1form_1_1XFormController.html#ab82266caaabe89a1734c9316fbeb1b4d',1,'com::sun::star::form::XFormController::addActivateListener()']]],
+  ['addactivatelistener',['addActivateListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFormController.html#a78f46eba46a4d71fcfe3768cca3387a8',1,'com::sun::star::form::runtime::XFormController::addActivateListener()'],['../interfacecom_1_1sun_1_1star_1_1form_1_1XFormController.html#a688b0a9af936e24eb9d02e6a44a27319',1,'com::sun::star::form::XFormController::addActivateListener()']]],
   ['addactivationeventlistener',['addActivationEventListener',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XActivationBroadcaster.html#a194b20848ed5aeee85b4eb4a39977b02',1,'com::sun::star::sheet::XActivationBroadcaster']]],
   ['addadjustmentlistener',['addAdjustmentListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XScrollBar.html#a96e6f8b17b97ed1116348b912417733a',1,'com::sun::star::awt::XScrollBar::addAdjustmentListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinValue.html#acda38a94dcecdee1580af9e621ee41d9',1,'com::sun::star::awt::XSpinValue::addAdjustmentListener()']]],
   ['addapproveactionlistener',['addApproveActionListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XApproveActionBroadcaster.html#ae3c2fe3ff16d3088ed530dc8b7ad8bad',1,'com::sun::star::form::XApproveActionBroadcaster']]],
@@ -40,7 +40,7 @@ var searchData=
   ['addbatch',['addBatch',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XBatchExecution.html#a6ad6e03503d1c780380cf9115087578c',1,'com::sun::star::sdbc::XBatchExecution::addBatch()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XPreparedBatchExecution.html#a403a78f23cd236be35da641fbe511b4c',1,'com::sun::star::sdbc::XPreparedBatchExecution::addBatch()']]],
   ['addbccrecipient',['addBccRecipient',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#ab80768ff13f5fb64c09cecce7ac3d166',1,'com::sun::star::mail::XMailMessage']]],
   ['addblocker',['addBlocker',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSAXEventKeeper.html#a920be90d99f09415b904535edecfe94b',1,'com::sun::star::xml::crypto::sax::XSAXEventKeeper']]],
-  ['addborder',['addBorder',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XPaneBorderPainter.html#ac2df1c3875a7d3e8f2003ecf6dd81977',1,'com::sun::star::drawing::framework::XPaneBorderPainter']]],
+  ['addborder',['addBorder',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XPaneBorderPainter.html#a94a389c5be60939c9a05f70c2dfab808',1,'com::sun::star::drawing::framework::XPaneBorderPainter']]],
   ['addborderresizelistener',['addBorderResizeListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XControllerBorder.html#aa774a1b0072c4216adf3303d9ef67a4a',1,'com::sun::star::frame::XControllerBorder']]],
   ['addbottom',['addBottom',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2.html#a0601637541f5b16cd7be0eba9ca871d0',1,'com::sun::star::drawing::XShapes2']]],
   ['addcallback',['addCallback',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XRequestCallback.html#acaac2cfd88943505bf3abb3bac2b6fda',1,'com::sun::star::awt::XRequestCallback']]],
@@ -54,10 +54,10 @@ var searchData=
   ['addclipboard',['addClipboard',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XClipboardManager.html#af17ea2616af5b3fe4594f9f2e14ef062',1,'com::sun::star::datatransfer::clipboard::XClipboardManager']]],
   ['addclipboardlistener',['addClipboardListener',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XClipboardNotifier.html#a5b585ed8f677f374abdb9826bf2469df',1,'com::sun::star::datatransfer::clipboard::XClipboardNotifier']]],
   ['addcloselistener',['addCloseListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XCloseBroadcaster.html#aed88b77cbda5ecb2649e55a24b3742bc',1,'com::sun::star::util::XCloseBroadcaster']]],
-  ['addcolumn',['addColumn',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#ab064f180662d0e5f31536f21e9247037',1,'com::sun::star::awt::grid::XGridColumnModel::addColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XTableAlteration.html#a93a193bb1dc48a1f507b3a0b70c23126',1,'com::sun::star::sdb::tools::XTableAlteration::addColumn()']]],
+  ['addcolumn',['addColumn',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumnModel.html#ab064f180662d0e5f31536f21e9247037',1,'com::sun::star::awt::grid::XGridColumnModel::addColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XTableAlteration.html#ae899239fac0712c4510649915d21676d',1,'com::sun::star::sdb::tools::XTableAlteration::addColumn()']]],
   ['addcommandinfochangelistener',['addCommandInfoChangeListener',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XCommandInfoChangeNotifier.html#abf377d06fe510fc8c00b8d2f0e0c84ad',1,'com::sun::star::ucb::XCommandInfoChangeNotifier']]],
   ['addconfigurationchangelistener',['addConfigurationChangeListener',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationControllerBroadcaster.html#ac76a50a74fcc9babbe811889412af1ac',1,'com::sun::star::drawing::framework::XConfigurationControllerBroadcaster']]],
-  ['addconfigurationlistener',['addConfigurationListener',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XUIConfiguration.html#af54b43a4c80d1f07658f9e6c0af5d3ac',1,'com::sun::star::ui::XUIConfiguration']]],
+  ['addconfigurationlistener',['addConfigurationListener',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XUIConfiguration.html#a8b4c2d654f49f325ec8587133843b429',1,'com::sun::star::ui::XUIConfiguration']]],
   ['addconfirmdeletelistener',['addConfirmDeleteListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XConfirmDeleteBroadcaster.html#aa02644a0e6ed33c1258635efbe732ad9',1,'com::sun::star::form::XConfirmDeleteBroadcaster']]],
   ['addconnectionlistener',['addConnectionListener',['../interfacecom_1_1sun_1_1star_1_1mail_1_1XMailService.html#a9e28e76ba5160a4bd920d5c2b3f520ed',1,'com::sun::star::mail::XMailService']]],
   ['addconsumer',['addConsumer',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XImageProducer.html#a4bcd17c46059c79a246227b003cccc11',1,'com::sun::star::awt::XImageProducer']]],
@@ -99,22 +99,22 @@ var searchData=
   ['addfilepickerlistener',['addFilePickerListener',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePickerNotifier.html#a95de96f8c3c18694cc4bf5dbcd60ca5d',1,'com::sun::star::ui::dialogs::XFilePickerNotifier']]],
   ['addfiltercontrollerlistener',['addFilterControllerListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterController.html#a9eeba5469e2cd4268067dfe07321934d',1,'com::sun::star::form::runtime::XFilterController']]],
   ['addflushlistener',['addFlushListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XFlushable.html#ae8887e4c65127748b094256f55d1e49a',1,'com::sun::star::util::XFlushable']]],
-  ['addfocuslistener',['addFocusListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#ae1df03f3ca83848a797ddb29aeb57e77',1,'com::sun::star::awt::XExtendedToolkit::addFocusListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#a763278575fdb119824139c5427bba080',1,'com::sun::star::awt::XWindow::addFocusListener()']]],
+  ['addfocuslistener',['addFocusListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#abe1d6890f9685778ec2edefcb386cd6a',1,'com::sun::star::awt::XExtendedToolkit::addFocusListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#a763278575fdb119824139c5427bba080',1,'com::sun::star::awt::XWindow::addFocusListener()']]],
   ['addformcomponentvaliditylistener',['addFormComponentValidityListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1validation_1_1XValidatableFormComponent.html#a353ca4240bd1c53ac85d20a208317bee',1,'com::sun::star::form::validation::XValidatableFormComponent']]],
   ['addframeactionlistener',['addFrameActionListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame.html#a97bda1557ab72b065d20dab24d69ec16',1,'com::sun::star::frame::XFrame']]],
   ['addgridcolumnlistener',['addGridColumnListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumn.html#ac1574f755505c0195259f3d5aa1eed61',1,'com::sun::star::awt::grid::XGridColumn']]],
   ['addgridcontrollistener',['addGridControlListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XGridControl.html#af47f96b6923b0b125c8f3ad88f29cf80',1,'com::sun::star::form::XGridControl']]],
   ['addgriddatalistener',['addGridDataListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XMutableGridDataModel.html#afc4557b96820dab64779954cdc52a7cc',1,'com::sun::star::awt::grid::XMutableGridDataModel']]],
   ['addgroup',['addGroup',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDocumentTemplates.html#a5aa38b422b26f9a9f4e48ecf5647405c',1,'com::sun::star::frame::XDocumentTemplates']]],
-  ['addindex',['addIndex',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XIndexAlteration.html#a867cfc00febaf1cf7107552c3fb0d5bd',1,'com::sun::star::sdb::tools::XIndexAlteration']]],
+  ['addindex',['addIndex',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XIndexAlteration.html#ae781ec8fc4fdab70469dc998d4ef7f28',1,'com::sun::star::sdb::tools::XIndexAlteration']]],
   ['addinstance',['addInstance',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSchemaHandler.html#a37fd15017ca0aa368bc92a347be8b1d2',1,'com::sun::star::configuration::backend::XSchemaHandler']]],
   ['additem',['addItem',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#aeaccefb51cf16cb59002f193de78d47d',1,'com::sun::star::awt::XComboBox::addItem()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#aeaccefb51cf16cb59002f193de78d47d',1,'com::sun::star::awt::XListBox::addItem()']]],
   ['additemlistener',['addItemListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XCheckBox.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XCheckBox::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XComboBox::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XItemEventBroadcaster.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XItemEventBroadcaster::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XListBox::addItemListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XRadioButton.html#a711aeec4818cf2dbc80db0252c3d021a',1,'com::sun::star::awt::XRadioButton::addItemListener()']]],
   ['additemlistlistener',['addItemListListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XItemList.html#ade08775aac4a0a4cb1cb8515bb8ea866',1,'com::sun::star::awt::XItemList']]],
   ['additems',['addItems',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html#a58381946105033d66f320708c10df295',1,'com::sun::star::awt::XComboBox::addItems()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XListBox.html#a58381946105033d66f320708c10df295',1,'com::sun::star::awt::XListBox::addItems()']]],
   ['additemtype',['addItemType',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSchemaHandler.html#a1914bd60d9bd3f507e2f36efa1541cf2',1,'com::sun::star::configuration::backend::XSchemaHandler']]],
-  ['addkey',['addKey',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XKeyAlteration.html#ac60fdea31e896a6334c90b4a663279a4',1,'com::sun::star::sdb::tools::XKeyAlteration']]],
-  ['addkeyhandler',['addKeyHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#a51f8ade556e5b7b64ec6ca4eeae23baa',1,'com::sun::star::awt::XExtendedToolkit::addKeyHandler()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html#a51f8ade556e5b7b64ec6ca4eeae23baa',1,'com::sun::star::awt::XUserInputInterception::addKeyHandler()']]],
+  ['addkey',['addKey',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1tools_1_1XKeyAlteration.html#a2c970259c4ad6ef128554e80256c2465',1,'com::sun::star::sdb::tools::XKeyAlteration']]],
+  ['addkeyhandler',['addKeyHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#a809925223ace2ecea73aa7399a6cc26b',1,'com::sun::star::awt::XExtendedToolkit::addKeyHandler()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html#a809925223ace2ecea73aa7399a6cc26b',1,'com::sun::star::awt::XUserInputInterception::addKeyHandler()']]],
   ['addkeylistener',['addKeyListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#a9af3815ac9284f4feb77310df0258f7a',1,'com::sun::star::awt::XWindow']]],
   ['addlayoutmanagereventlistener',['addLayoutManagerEventListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManagerEventBroadcaster.html#afb0f895119cb38176fa847ade0c13fe5',1,'com::sun::star::frame::XLayoutManagerEventBroadcaster']]],
   ['addlinguserviceeventlistener',['addLinguServiceEventListener',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguServiceEventBroadcaster.html#a2f466ba7bfa9f1e0801413dc3c209bb5',1,'com::sun::star::linguistic2::XLinguServiceEventBroadcaster']]],
@@ -132,11 +132,11 @@ var searchData=
   ['addmodechangelistener',['addModeChangeListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa941e5eab44274eb697756310fb21a18',1,'com::sun::star::util::XModeChangeBroadcaster']]],
   ['addmodifylistener',['addModifyListener',['../interfacecom_1_1sun_1_1star_1_1util_1_1XModifyBroadcaster.html#a419e56cf6f53f208a01cf7d307a1cc02',1,'com::sun::star::util::XModifyBroadcaster']]],
   ['addmodule',['addModule',['../interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#a287512fb488dbd9343e42b2a560d7b96',1,'com::sun::star::script::XStarBasicAccess']]],
-  ['addmouseclickhandler',['addMouseClickHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html#a95fcc41b75044136c7c51a4b9f92ae51',1,'com::sun::star::awt::XUserInputInterception']]],
+  ['addmouseclickhandler',['addMouseClickHandler',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html#ad50d348c8d466781e975210b0fcbbb38',1,'com::sun::star::awt::XUserInputInterception']]],
   ['addmouselistener',['addMouseListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#a1e044b9120d0e98c33b7ead0b48fe424',1,'com::sun::star::awt::XWindow::addMouseListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#a1e044b9120d0e98c33b7ead0b48fe424',1,'com::sun::star::presentation::XSlideShowView::addMouseListener()']]],
   ['addmousemotionlistener',['addMouseMotionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#ae070b13efce39ce3be3ae1c4e79bc28f',1,'com::sun::star::awt::XWindow::addMouseMotionListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#ae070b13efce39ce3be3ae1c4e79bc28f',1,'com::sun::star::presentation::XSlideShowView::addMouseMotionListener()']]],
   ['addnew',['addNew',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XLabelRanges.html#a0ad033b87ffc6cbdddf9a7156cfaad14',1,'com::sun::star::sheet::XLabelRanges::addNew()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetConditionalEntries.html#ae6003e13d9f4a9723070b73f4b62c818',1,'com::sun::star::sheet::XSheetConditionalEntries::addNew()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XSubTotalDescriptor.html#a1bd93b2f4fa33ccac502c026cf7f0211',1,'com::sun::star::sheet::XSubTotalDescriptor::addNew()'],['../interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormats.html#a59917c16b14b9efcf3aa52d34664ebda',1,'com::sun::star::util::XNumberFormats::addNew()']]],
-  ['addnewbyname',['addNewByName',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRanges.html#ab60de80c3c8cc0e511f524e75da71b27',1,'com::sun::star::sheet::XDatabaseRanges::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges.html#a3c711a36569e35784a4ec1bda04c59f7',1,'com::sun::star::sheet::XNamedRanges::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenarios.html#a9fb10e572951e1ff4866b904cca0c31a',1,'com::sun::star::sheet::XScenarios::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1table_1_1XTableCharts.html#a0792f7036c00cfbec9fa04781de401ce',1,'com::sun::star::table::XTableCharts::addNewByName()']]],
+  ['addnewbyname',['addNewByName',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XDatabaseRanges.html#ab60de80c3c8cc0e511f524e75da71b27',1,'com::sun::star::sheet::XDatabaseRanges::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges.html#a3c711a36569e35784a4ec1bda04c59f7',1,'com::sun::star::sheet::XNamedRanges::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XScenarios.html#a9fb10e572951e1ff4866b904cca0c31a',1,'com::sun::star::sheet::XScenarios::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1table_1_1XTableCharts.html#a0792f7036c00cfbec9fa04781de401ce',1,'com::sun::star::table::XTableCharts::addNewByName()'],['../interfacecom_1_1sun_1_1star_1_1table_1_1XTablePivotCharts.html#acece64837d96a30692e5823466f9d805',1,'com::sun::star::table::XTablePivotCharts::addNewByName()']]],
   ['addnewconverted',['addNewConverted',['../interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormats.html#afcc1a2d6ec3aa6473c5750ddb448f395',1,'com::sun::star::util::XNumberFormats']]],
   ['addnewdictionary',['addNewDictionary',['../interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XConversionDictionaryList.html#a37d678d62d16ebfc693710ddddaa4ade',1,'com::sun::star::linguistic2::XConversionDictionaryList']]],
   ['addnewfromtitles',['addNewFromTitles',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XNamedRanges.html#abb672a31fc3b27403d5583f272747fee',1,'com::sun::star::sheet::XNamedRanges']]],
@@ -145,11 +145,11 @@ var searchData=
   ['addorreplaceproperty',['addOrReplaceProperty',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdateHandler.html#a5bd0d79c693d22565279892dc3ecab21',1,'com::sun::star::configuration::backend::XUpdateHandler']]],
   ['addorreplacepropertywithvalue',['addOrReplacePropertyWithValue',['../interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XUpdateHandler.html#a18696c86e13e67ddfcdf4440cdbc335c',1,'com::sun::star::configuration::backend::XUpdateHandler']]],
   ['addpackage',['addPackage',['../interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackageManager.html#a47b03bd6f75a3b1fcda1124c8051304b',1,'com::sun::star::deployment::XPackageManager']]],
-  ['addpaintlistener',['addPaintListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#ac2d3d0d86ad766349c6009586444dc7c',1,'com::sun::star::awt::XWindow::addPaintListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#aa9c94eb039df4b9d531e3ae59e238ec1',1,'com::sun::star::presentation::XSlideShowView::addPaintListener()']]],
+  ['addpaintlistener',['addPaintListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindow.html#ac2d3d0d86ad766349c6009586444dc7c',1,'com::sun::star::awt::XWindow::addPaintListener()'],['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#af9121b15344b239fa0ad32b643b1bee9',1,'com::sun::star::presentation::XSlideShowView::addPaintListener()']]],
   ['addparameterlistener',['addParameterListener',['../interfacecom_1_1sun_1_1star_1_1form_1_1XDatabaseParameterBroadcaster.html#af1574e47af370be6f56b96530700ad44',1,'com::sun::star::form::XDatabaseParameterBroadcaster']]],
   ['addpassword',['addPassword',['../interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOPasswordCache.html#a07c78d8fbdd99fbb30e6849d54166a11',1,'com::sun::star::auth::XSSOPasswordCache']]],
   ['addpersistent',['addPersistent',['../interfacecom_1_1sun_1_1star_1_1task_1_1XPasswordContainer.html#a3d1ef8863dbb27e0c0265f60829a3bd2',1,'com::sun::star::task::XPasswordContainer']]],
-  ['addpolypolygon',['addPolyPolygon',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XPolyPolygon2D.html#ae0d4b4169ad639a82be3eedeac81a88e',1,'com::sun::star::rendering::XPolyPolygon2D']]],
+  ['addpolypolygon',['addPolyPolygon',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XPolyPolygon2D.html#abc07c3697b3bcbd14abcac098328eb40',1,'com::sun::star::rendering::XPolyPolygon2D']]],
   ['addpreviewcreationnotifylistener',['addPreviewCreationNotifyListener',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCache.html#a52c8455fb5bcd2278a6c22779503bf88',1,'com::sun::star::drawing::XSlidePreviewCache']]],
   ['addprintablelistener',['addPrintableListener',['../interfacecom_1_1sun_1_1star_1_1view_1_1XPrintableBroadcaster.html#a7f6b75d8edd1d0df8cc0727d5284f847',1,'com::sun::star::view::XPrintableBroadcaster']]],
   ['addprintjoblistener',['addPrintJobListener',['../interfacecom_1_1sun_1_1star_1_1view_1_1XPrintJobBroadcaster.html#a8236dc1938be371a19d1744aa4e05144',1,'com::sun::star::view::XPrintJobBroadcaster']]],
@@ -190,7 +190,7 @@ var searchData=
   ['addselectionlistener',['addSelectionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridRowSelection.html#afce56177e29a07ffc2019a2ce0cd6f8a',1,'com::sun::star::awt::grid::XGridRowSelection']]],
   ['addsessionmanagerlistener',['addSessionManagerListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSessionManagerClient.html#a92a191324673afac3946aa42c7a675ba',1,'com::sun::star::frame::XSessionManagerClient']]],
   ['addshape',['addShape',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartShapeContainer.html#a3de1e4719bf42d5b727e7867f9cd2544',1,'com::sun::star::chart2::XChartShapeContainer']]],
-  ['addshapeeventlistener',['addShapeEventListener',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#a11daa72242b7f516f94ce94b3f278083',1,'com::sun::star::presentation::XSlideShow']]],
+  ['addshapeeventlistener',['addShapeEventListener',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#ac337a7888beb33e0f5b512d223104b05',1,'com::sun::star::presentation::XSlideShow']]],
   ['addsheetcache',['addSheetCache',['../interfacecom_1_1sun_1_1star_1_1sheet_1_1XExternalDocLink.html#a6f41bd654a62328a634624cccba0fd68',1,'com::sun::star::sheet::XExternalDocLink']]],
   ['addsignaturecreationresultlistener',['addSignatureCreationResultListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSignatureCreationResultBroadcaster.html#ab14c57294f09b8295c1c5240944ea902',1,'com::sun::star::xml::crypto::sax::XSignatureCreationResultBroadcaster']]],
   ['addsignatureverifyresultlistener',['addSignatureVerifyResultListener',['../interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1XSignatureVerifyResultBroadcaster.html#aedf5643d0a54876a41073e18bc76ed92',1,'com::sun::star::xml::crypto::sax::XSignatureVerifyResultBroadcaster']]],
@@ -215,9 +215,9 @@ var searchData=
   ['addtextlistener',['addTextListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTextComponent.html#a3b1b9fe71c13651bc329a2b7f95bbade',1,'com::sun::star::awt::XTextComponent']]],
   ['addtitlechangelistener',['addTitleChangeListener',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTitleChangeBroadcaster.html#a27b78b049ab3a962570ef84a66c20cb8',1,'com::sun::star::frame::XTitleChangeBroadcaster']]],
   ['addtop',['addTop',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapes2.html#a57750456be913dd8235bfee8678dd94c',1,'com::sun::star::drawing::XShapes2']]],
-  ['addtopwindowlistener',['addTopWindowListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#a4b5c9b2508b87e7d3ef01bef5431fead',1,'com::sun::star::awt::XExtendedToolkit::addTopWindowListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html#ab7d6cd17c0ee033522af72a76a3ae4f0',1,'com::sun::star::awt::XTopWindow::addTopWindowListener()']]],
+  ['addtopwindowlistener',['addTopWindowListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XExtendedToolkit.html#a3157d6b441fa1c158a0af83c749bc6d4',1,'com::sun::star::awt::XExtendedToolkit::addTopWindowListener()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html#ab7d6cd17c0ee033522af72a76a3ae4f0',1,'com::sun::star::awt::XTopWindow::addTopWindowListener()']]],
   ['addtransactionlistener',['addTransactionListener',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XTransactionBroadcaster.html#ad3fe6566514f33afd9bbd7a203a7b8cf',1,'com::sun::star::embed::XTransactionBroadcaster']]],
-  ['addtransformationchangedlistener',['addTransformationChangedListener',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#a03d7bd22af60153b06891634c4b80959',1,'com::sun::star::presentation::XSlideShowView']]],
+  ['addtransformationchangedlistener',['addTransformationChangedListener',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShowView.html#a9896e738f1d7c12d3769f84b7bd3f034',1,'com::sun::star::presentation::XSlideShowView']]],
   ['addtreedatamodellistener',['addTreeDataModelListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModel.html#aba9d0dfec03d9f47f99550ac6c3e023e',1,'com::sun::star::awt::tree::XTreeDataModel']]],
   ['addtreeeditlistener',['addTreeEditListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeControl.html#ab9d26d28eb97f9b64ba9621a879c6a84',1,'com::sun::star::awt::tree::XTreeControl']]],
   ['addtreeexpansionlistener',['addTreeExpansionListener',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeControl.html#a0c6aeb5ca502311c4d6cddaf6934a540',1,'com::sun::star::awt::tree::XTreeControl']]],
@@ -238,9 +238,9 @@ var searchData=
   ['advise',['advise',['../interfacecom_1_1sun_1_1star_1_1lang_1_1XConnectionPoint.html#a0331c710da22857ced9b2067f0fd74b0',1,'com::sun::star::lang::XConnectionPoint::advise()'],['../interfacecom_1_1sun_1_1star_1_1lang_1_1XConnectionPointContainer.html#abb8c562b201482b635f941f57d3ffe0d',1,'com::sun::star::lang::XConnectionPointContainer::advise()']]],
   ['afterlast',['afterLast',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSet.html#a4220bd65ccca989e491fc4e75c3ac6e3',1,'com::sun::star::sdbc::XResultSet']]],
   ['alignshapes',['alignShapes',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeAligner.html#a160845d4c3cd104939166e034f3022ea',1,'com::sun::star::drawing::XShapeAligner']]],
-  ['allactionscleared',['allActionsCleared',['../interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManagerListener.html#a15069eab4c9d907e58e32b5a2445e96e',1,'com::sun::star::document::XUndoManagerListener']]],
+  ['allactionscleared',['allActionsCleared',['../interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManagerListener.html#a123b583f319b865beb2e4868e246f78c',1,'com::sun::star::document::XUndoManagerListener']]],
   ['allentrieschanged',['allEntriesChanged',['../interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XListEntryListener.html#a62236670c0a35a3acdd60d05c3080c2f',1,'com::sun::star::form::binding::XListEntryListener']]],
-  ['allitemsremoved',['allItemsRemoved',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XItemListListener.html#ad6f1ec0568755d64b992397aaa3b981e',1,'com::sun::star::awt::XItemListListener']]],
+  ['allitemsremoved',['allItemsRemoved',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XItemListListener.html#a6670e12a4d5e69bd51b0c7f6233ffc95',1,'com::sun::star::awt::XItemListListener']]],
   ['allowlinebreak',['allowLineBreak',['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XExtendedDocumentHandler.html#ac415a427ae393ebf4ead6eb84bcb2090',1,'com::sun::star::xml::sax::XExtendedDocumentHandler']]],
   ['allowpersistentstoring',['allowPersistentStoring',['../interfacecom_1_1sun_1_1star_1_1task_1_1XMasterPasswordHandling.html#ad95acad92f04fb2e6db315fae44d3b86',1,'com::sun::star::task::XMasterPasswordHandling']]],
   ['allproceduresarecallable',['allProceduresAreCallable',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a74240a53ecf8b25ceb385a85ad18f3da',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
@@ -254,10 +254,10 @@ var searchData=
   ['appenddata',['appendData',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XCharacterData.html#afeeb74b5488625cb104f6a4892371d5d',1,'com::sun::star::xml::dom::XCharacterData']]],
   ['appendemptydisjunctiveterm',['appendEmptyDisjunctiveTerm',['../interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterController.html#a3470aa686dc2f42360375a3e501038fc',1,'com::sun::star::form::runtime::XFilterController']]],
   ['appendfilter',['appendFilter',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilterManager.html#ae6c608a77c755b24972d5d8abbddc1d4',1,'com::sun::star::ui::dialogs::XFilterManager']]],
-  ['appendfilterbycolumn',['appendFilterByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#aee7972fc941ba654881f7a9952003b1e',1,'com::sun::star::sdb::XSingleSelectQueryComposer::appendFilterByColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLQueryComposer.html#a9b18fdf74b45432013719766f20f80e9',1,'com::sun::star::sdb::XSQLQueryComposer::appendFilterByColumn()']]],
+  ['appendfilterbycolumn',['appendFilterByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a775b31c0fdbe7ef9284d37303b8dd95a',1,'com::sun::star::sdb::XSingleSelectQueryComposer::appendFilterByColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLQueryComposer.html#a9b18fdf74b45432013719766f20f80e9',1,'com::sun::star::sdb::XSQLQueryComposer::appendFilterByColumn()']]],
   ['appendfiltergroup',['appendFilterGroup',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilterGroupManager.html#ab08eeed36f60dc31614acf5f32fe7ae5',1,'com::sun::star::ui::dialogs::XFilterGroupManager']]],
   ['appendgroupbycolumn',['appendGroupByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a648f70c26079abaac487e2b59eaad57c',1,'com::sun::star::sdb::XSingleSelectQueryComposer']]],
-  ['appendhavingclausebycolumn',['appendHavingClauseByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#aa0a1402a610bedb37d4eb3e0865401ac',1,'com::sun::star::sdb::XSingleSelectQueryComposer']]],
+  ['appendhavingclausebycolumn',['appendHavingClauseByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#a05cacbf03e4b5bb7428574f1707abc6e',1,'com::sun::star::sdb::XSingleSelectQueryComposer']]],
   ['appendlistentry',['appendListEntry',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XStringListControl.html#a1c2fac71d01569750412b43126424783',1,'com::sun::star::inspection::XStringListControl']]],
   ['appendorderbycolumn',['appendOrderByColumn',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#aa8cee7548668952177c86459058c328e',1,'com::sun::star::sdb::XSingleSelectQueryComposer::appendOrderByColumn()'],['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XSQLQueryComposer.html#aa8cee7548668952177c86459058c328e',1,'com::sun::star::sdb::XSQLQueryComposer::appendOrderByColumn()']]],
   ['appendsequence',['appendSequence',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XInternalDataProvider.html#a93bce9d0d78a70fe871bb7c463add211',1,'com::sun::star::chart2::XInternalDataProvider']]],
